# PyPetrophysics
This is a python package containing a number of common petrophysical calculations that can be quickly called upon.

# Status
![Tests](https://github.com/andymcdgeo/PyPetrophysics/workflows/Tests/badge.svg?branch=master) ![Test Coverage](https://img.shields.io/codecov/c/github/andymcdgeo/PyPetrophysics/master?color=%2334a1eb&label=Test%20Coverage) [![PyPI](https://img.shields.io/pypi/v/PyPetrophysics.svg)](https://pypi.org/project/PyPetrophysics/) ![Hex.pm](https://img.shields.io/hexpm/l/plug) 

# Install
To install, use the following command:  
  
  `pip install pypetrophysics`

# Documentation
Documentation is available at:
https://pypetrophysics.readthedocs.io/en/latest/index.html

# Reporting Issues
I would love to hear from you if you have come across any bugs, errors or suggestions. To create a new issue, click on the issues tab at the top of the repo and create a new case.

